==> jc-1.4.0.tar.gz: javax/transaction/TransactionRolledbackException.h <==
// public class javax.transaction.TransactionRolledbackException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class 24bead986c156765 javax_transaction_TransactionRolledbackException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_javax_transaction_TransactionRolledbackException_H_
#define _JC_javax_transaction_TransactionRolledbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_TransactionRolledbackException$sub_refs	_jc_javax_transaction_TransactionRolledbackException$sub_refs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$sub_nonrefs	_jc_javax_transaction_TransactionRolledbackException$sub_nonrefs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$refs	_jc_javax_transaction_TransactionRolledbackException$refs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$nonrefs	_jc_javax_transaction_TransactionRolledbackException$nonrefs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$object	_jc_javax_transaction_TransactionRolledbackException$object;

typedef const struct _jc_javax_transaction_TransactionRolledbackException$vmethods	_jc_javax_transaction_TransactionRolledbackException$vmethods;
typedef const struct _jc_javax_transaction_TransactionRolledbackException$vtable	_jc_javax_transaction_TransactionRolledbackException$vtable;
typedef const struct _jc_javax_transaction_TransactionRolledbackException$vtype	_jc_javax_transaction_TransactionRolledbackException$vtype;

// Constructors
extern void _jc_javax_transaction_TransactionRolledbackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_TransactionRolledbackException$object *);
extern void _jc_javax_transaction_TransactionRolledbackException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_TransactionRolledbackException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_transaction_TransactionRolledbackException$vmethods {
};

// Vtable
struct _jc_javax_transaction_TransactionRolledbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_javax_transaction_TransactionRolledbackException$vmethods	javax_transaction_TransactionRolledbackException;
};

// Vtype
struct _jc_javax_transaction_TransactionRolledbackException$vtype {
	_jc_type			type;
	_jc_javax_transaction_TransactionRolledbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRolledbackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_TransactionRolledbackException$refs {
    _jc_javax_transaction_TransactionRolledbackException$sub_refs	javax_transaction_TransactionRolledbackException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRolledbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_TransactionRolledbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_javax_transaction_TransactionRolledbackException$sub_nonrefs	javax_transaction_TransactionRolledbackException;
};

// Object instance structure
struct _jc_javax_transaction_TransactionRolledbackException$object {
	_jc_javax_transaction_TransactionRolledbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_TransactionRolledbackException$vtype	*vtype;
	_jc_javax_transaction_TransactionRolledbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_TransactionRolledbackException$vtype _jc_javax_transaction_TransactionRolledbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_TransactionRolledbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_TransactionRolledbackException$class_object;

#endif	/* _JC_javax_transaction_TransactionRolledbackException_H_ */

==> jc-1.4.6.tar.gz: javax/transaction/TransactionRolledbackException.h <==
// public class javax.transaction.TransactionRolledbackException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class 24bead986c156765 javax_transaction_TransactionRolledbackException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_javax_transaction_TransactionRolledbackException_H_
#define _JC_javax_transaction_TransactionRolledbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_TransactionRolledbackException$sub_refs	_jc_javax_transaction_TransactionRolledbackException$sub_refs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$sub_nonrefs	_jc_javax_transaction_TransactionRolledbackException$sub_nonrefs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$refs	_jc_javax_transaction_TransactionRolledbackException$refs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$nonrefs	_jc_javax_transaction_TransactionRolledbackException$nonrefs;
typedef struct _jc_javax_transaction_TransactionRolledbackException$object	_jc_javax_transaction_TransactionRolledbackException$object;

typedef const struct _jc_javax_transaction_TransactionRolledbackException$vmethods	_jc_javax_transaction_TransactionRolledbackException$vmethods;
typedef const struct _jc_javax_transaction_TransactionRolledbackException$vtable	_jc_javax_transaction_TransactionRolledbackException$vtable;
typedef const struct _jc_javax_transaction_TransactionRolledbackException$vtype	_jc_javax_transaction_TransactionRolledbackException$vtype;

// Constructors
extern void _jc_javax_transaction_TransactionRolledbackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_TransactionRolledbackException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_TransactionRolledbackException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_TransactionRolledbackException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_transaction_TransactionRolledbackException$vmethods {
};

// Vtable
struct _jc_javax_transaction_TransactionRolledbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_javax_transaction_TransactionRolledbackException$vmethods	javax_transaction_TransactionRolledbackException;
};

// Vtype
struct _jc_javax_transaction_TransactionRolledbackException$vtype {
	_jc_type			type;
	_jc_javax_transaction_TransactionRolledbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRolledbackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_TransactionRolledbackException$refs {
    _jc_javax_transaction_TransactionRolledbackException$sub_refs	javax_transaction_TransactionRolledbackException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRolledbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_TransactionRolledbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_javax_transaction_TransactionRolledbackException$sub_nonrefs	javax_transaction_TransactionRolledbackException;
};

// Object instance structure
struct _jc_javax_transaction_TransactionRolledbackException$object {
	_jc_javax_transaction_TransactionRolledbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_TransactionRolledbackException$vtype	*vtype;
	_jc_javax_transaction_TransactionRolledbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_TransactionRolledbackException$vtype _jc_javax_transaction_TransactionRolledbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_TransactionRolledbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_TransactionRolledbackException$class_object;

#endif	/* _JC_javax_transaction_TransactionRolledbackException_H_ */
